---
layout: page
title: proxmox_virtual_environment_acme_account
parent: Data Sources
subcategory: Virtual Environment
description: |-
  Retrieves information about a specific ACME account.
---

# Data Source: proxmox_virtual_environment_acme_account

Retrieves information about a specific ACME account.

## Example Usage

```terraform
// This will fetch all ACME accounts...
data "proxmox_virtual_environment_acme_accounts" "all" {}

// ...which we will go through in order to fetch the whole data on each account.
data "proxmox_virtual_environment_acme_account" "example" {
  for_each = data.proxmox_virtual_environment_acme_accounts.all.accounts
  name     = each.value
}

output "data_proxmox_virtual_environment_acme_account" {
  value = data.proxmox_virtual_environment_acme_account.example
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Optional

- `name` (String) The identifier of the ACME account to read.

### Read-Only

- `account` (Attributes) The ACME account information. (see [below for nested schema](#nestedatt--account))
- `directory` (String) The directory URL of the ACME account.
- `location` (String) The location URL of the ACME account.
- `tos` (String) The URL of the terms of service of the ACME account.

<a id="nestedatt--account"></a>
### Nested Schema for `account`

Read-Only:

- `contact` (List of String) An array of contact email addresses.
- `created_at` (String) The timestamp of the account creation.
- `status` (String) The status of the account. Can be one of `valid`, `deactivated` or `revoked`.
